<?php
/**
 * Clip Name: Krolyn YouTube Videos
 * Clip URI: https://clipbank.krolyn.com/clip/krolyn-youtube-videos
 * Description: This Clip adds a YouTube video channel or playlist stream via a shortcode.
 * Version: 1.0.2
 * Author: Krolyn Studios
 * Author URI: https://krolyn.au
 */

class Krolyn_YouTube_Videos_Clip {

	public function __construct() {
		add_action( 'wp_enqueue_scripts', [ $this, 'krolyn_videos_scripts' ] );
		add_shortcode( 'krolyn_youtube_videos', [ $this, 'krolyn_videos_shortcode' ] );
	}

	// Get channel ID
	public function krolyn_videos_scripts() {

		$path = site_url( '/' . substr( dirname(__FILE__), strlen( ABSPATH ) ) );

		wp_enqueue_script(	'krolyn-videos-script',
							$path . '/clip-script.js',
							['jquery'],
							'1.0', true
				);
		wp_enqueue_style(  'krolyn-videos-style', 
							$path . '/clip-style.css',
							'1.0'
				);
	}

	public function krolyn_videos_shortcode( $atts ) {

		extract( shortcode_atts( array(
			'api'			=> '',
			'channel_id'	=> '',
			'playlist_id'	=> '',
			'qty'			=> 10,
			'caption'		=> '1',
			'desc_length'	=> 50,
			'modal'			=> '0',
			'unlisted'		=> '0'
			
		), $atts) );

		if( empty( $api ) || empty( $channel_id ) ) return;

		$caption = ( in_array( $caption, [ 'false', '0', 'no' ] ) ) ? 0 : 1;
		$modal = ( in_array( $modal, [ 'true', '1', 'yes' ] ) ) ? 1 : 0;
		$unlisted = ( in_array( $unlisted, [ 'true', '1', 'yes' ] ) ) ? 1 : 0;

		if( empty( $playlist_id ) ) {

			$channel_url = "https://www.googleapis.com/youtube/v3/channels?part=contentDetails&id={$channel_id}&key={$api}";
			$channel_data = file_get_contents( $channel_url );
			$getChannelData = json_decode( $channel_data, true );
			$playlist_id = $getChannelData['items'][0]['contentDetails']['relatedPlaylists']['uploads'];
		}

		$playlist_url = "https://www.googleapis.com/youtube/v3/playlistItems?part=contentDetails,snippet,status&maxResults={$qty}&playlistId={$playlist_id}&key={$api}";
		$playlist_data = @file_get_contents( $playlist_url );
		$data = json_decode( $playlist_data, true );
		
		ob_start();

		if( is_wp_error( $data ) || empty( $data ) ) {     
			echo '<br /><p>' . __( 'Sorry, there are no items available.', 'wp-clips' ) . '</p>';
		}
		else {
			?>
			<ul id="krolyn-videos" class="<?php echo ( $modal ? 'modal' : '' ); ?>" >
            <?php

				foreach( $data['items'] as $k => $v) {

					$priv = $v['status']['privacyStatus'];
					if( $priv === 'private' || ( ! $unlisted && $priv === 'unlisted' ) ) continue;

					$id = $v['contentDetails']['videoId'];
					$title = $v['snippet']['title'];
					$thumb = $v['snippet']['thumbnails']['medium']['url'];
					$excerpt = $v['snippet']['description'];
					$more = "https://www.youtube.com/watch?v={$id}";
					$link = "https://www.youtube.com/embed/{$id}?autoplay=1";

					?>
                    <li>

                        <?php
                        if( $modal ) {
							?>
                            <a href="#modal" class="modal-toggle" data-modal-type="video" data-modal-content="<?php echo $link; ?>" title="<?php echo $title; ?>" />
                                <img src="<?php echo $thumb; ?>" alt="<?php echo $title; ?>" />
                                <?php
								if( $caption ) { ?>
									<h4><?php echo $title; ?></h4>
								<?php
								}
							?>
							</a>
                        <?php
						}
						else {
							?>
							<iframe width="560" height="315" src="https://www.youtube.com/embed/<?php echo $id; ?>" frameborder="0" allowfullscreen> </iframe> 
							<?php
							if( $caption ) { ?>
								<h4><?php echo $title; ?></h4>
							<?php
							} 
						}

						if( $caption && $desc_length && ! empty( $excerpt ) ) {

							$excerpt = strip_tags( str_replace( '</p>', ' ', $excerpt ) );
							$excerpt = explode( ' ', $excerpt, $desc_length );
							$key_last = intval( array_key_last( $excerpt ) );
							if( strpos( $excerpt[$key_last], ' ' ) !== false ) {
								$excerpt[$key_last] = '&hellip; <a href="'. $more . '" target="_blank">' . __( 'see more', 'wp-clips' ) . '</a>';
							}
							$excerpt = implode( ' ', $excerpt );
							?>
							<p><?php echo $excerpt; ?></p>
						<?php
						}

						unset( $priv, $id, $title, $thumb, $excerpt, $more, $link );
					?>
                    </li>
				<?php
				}
			?>
            </ul>
		<?php
		}
		
		$contents = ob_get_contents();
		ob_end_clean();

		return $contents;
	}
}

new Krolyn_YouTube_Videos_Clip();